You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by fu...@apache.org on 2007/03/08 23:25:48 UTC

svn commit: r516196 [2/3] - in /db/derby/code/trunk/java/engine/org/apache/derby/impl: jdbc/ jdbc/authentication/ load/ services/bytecode/ services/cache/ services/jce/ services/locks/ services/monitor/ services/reflect/ sql/ sql/catalog/ sql/compile/ ...

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/RawStore.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/RawStore.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocExtent.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocExtent.java Thu Mar  8 14:25:41 2007
@@ -337,7 +337,7 @@
 	/**
 		Allocate this page - this is called underneath the log record
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void allocPage(long pagenum) throws StandardException
 	{
@@ -405,7 +405,7 @@
 	    Deallocate logical page pagenum - this is called underneath the log record.
 		pagenum must be a page managed by this extent and it must be valid
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void deallocPage(long pagenum) throws StandardException
 	{
@@ -681,7 +681,7 @@
 
 		An exception is always thrown if pagenum is a free page
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected long getPageOffset(long pagenum, int pagesize, boolean deallocOK) throws StandardException
 	{

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocPage.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocPage.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocPage.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocPage.java Thu Mar  8 14:25:41 2007
@@ -524,7 +524,7 @@
 		also. Else check to make sure epage's original container info is of the
 		same length
 
-		@exception StandardException Cloudscape standard error policy
+		@exception StandardException standard Derby error policy
 	*/
 	public static void WriteContainerInfo(byte[] containerInfo,
 										  byte[] epage,
@@ -859,7 +859,7 @@
 	/**
 		Chain the next page number and offset underneath a log record
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void chainNextAllocPage(LogInstant instant,
 									  long newAllocPageNum,

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocationActions.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocationActions.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocationActions.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocationActions.java Thu Mar  8 14:25:41 2007
@@ -45,7 +45,7 @@
 		@param undoStatus		on undo, set the allocation status of the page
 								this value 
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void actionAllocatePage(RawTransaction t, BasePage allocPage, 
 								   long pageNumber, int doStatus, int undoStatus)
@@ -60,7 +60,7 @@
 		@param pageNumber		the next allocation page's number 
 		@param pageOffset		the next allocation page's page offset
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void actionChainAllocPage(RawTransaction t, BasePage allocPage, 
 								long pageNumber, long pageOffset)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainer.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainer.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainer.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainer.java Thu Mar  8 14:25:41 2007
@@ -173,7 +173,7 @@
         will usually mean releasing any free pages located at the end of the
         file using the java truncate() interface.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void compressContainer(BaseContainerHandle handle)
         throws StandardException
@@ -264,7 +264,7 @@
 
 		The user transaction is used to latch the newly created page.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Page addPage(BaseContainerHandle handle, boolean isOverflow) throws StandardException {
 		
@@ -399,7 +399,7 @@
 		@param handle the container handle that has opened the container and latched the page
 		@param page the latched page that is to be deallocated
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void removePage(BaseContainerHandle handle, BasePage page) 
 		 throws StandardException
@@ -441,7 +441,7 @@
 		Get the special dealloc lock on the page - the lock is gotten by the
 		transaction that owns the container handle
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected boolean getDeallocLock(BaseContainerHandle handle, 
 									 RecordHandle deallocLock, 
@@ -478,7 +478,7 @@
 
 	/**
 		Get an allocation page and latch it.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected Page getAllocPage(BaseContainerHandle handle, long pageNumber, boolean wait)
 		 throws StandardException
@@ -488,7 +488,7 @@
 
 	/**
 		Get any page and latch it .
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected Page getAnyPage(BaseContainerHandle handle, long pageNumber, boolean wait)
 		 throws StandardException
@@ -499,7 +499,7 @@
 
 	/**
 		Get the first valid page. Result is latched.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected Page getFirstPage(BaseContainerHandle handle) throws StandardException
 	{
@@ -508,7 +508,7 @@
 
 	/**
 		Get the next valid page and latch it
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected Page getNextPage(BaseContainerHandle handle, long pageNumber)
         throws StandardException
@@ -653,7 +653,7 @@
 		Return a BasePage that represents the given page number in this container.
         The resulting page is latched.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract BasePage getPage(BaseContainerHandle handle, long pageNumber,
         boolean wait) throws StandardException;
@@ -661,7 +661,7 @@
 	/**
 		Return a BasePage that represents the given alloc page number in this container.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract BasePage getAllocPage(long pageNumber) throws StandardException;
 
@@ -669,7 +669,7 @@
 		Return a BasePage that represents any page - alloc page, valid page, free page,
 		dealloced page etc.  The only requirement is that the page is initialized...
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	protected abstract BasePage getAnyPage(BaseContainerHandle handle, long pageNumber)
 		 throws StandardException;
@@ -720,7 +720,7 @@
 		Log all information on the container creation necessary to recreate teh
 		container during a load tran.
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	 protected abstract ByteArray logCreateContainerInfo()
 		 throws StandardException;
@@ -730,28 +730,28 @@
 		Get only a valid, non-overflow page.  If page number is either invalid
 		or overflow, returns null
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	protected abstract BasePage getHeadPage(BaseContainerHandle handle,
         long pagenumber, boolean wait) throws StandardException;
 
 	/**
 		Get the first page in the container.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract BasePage getFirstHeadPage(BaseContainerHandle handle,
         boolean wait) throws StandardException;
 
 	/**
 		Get the next page in the container.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract BasePage getNextHeadPage(BaseContainerHandle handle,
         long pageNumber, boolean wait) throws StandardException;
 
 	/**
 		Get a potentially suitable page for insert and latch it.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected abstract BasePage getPageForInsert(BaseContainerHandle handle,
 												 int flag)
@@ -770,7 +770,7 @@
 	/**
 		Create a new page in the container.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract BasePage newPage(BaseContainerHandle userhandle,
 										RawTransaction t,
@@ -786,7 +786,7 @@
 	/**
 		Deallocate a page from the container.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract void deallocatePage(BaseContainerHandle userhandle,
 										   BasePage page) throws StandardException;
@@ -814,21 +814,21 @@
 		@param leaveStub if true, leave a stub.  If false, remove everything
 		@see org.apache.derby.iapi.store.raw.data.RawContainerHandle#removeContainer
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract void removeContainer(LogInstant instant, boolean leaveStub) throws StandardException;
 
 	/**
 		Get the logged container version.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract long getContainerVersion() throws StandardException;
 
 	/**
 		Flush all outstanding changes in this container to persistent storage.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract void flushAll() throws StandardException;
 
@@ -850,19 +850,19 @@
 	*/
 	/**
 		@see ContainerHandle#getEstimatedRowCount
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public abstract long getEstimatedRowCount(int flag) throws StandardException;
 
 	/**
 		@see ContainerHandle#setEstimatedRowCount
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public abstract void setEstimatedRowCount(long count, int flag) throws StandardException;
 
 	/**
 		@see ContainerHandle#getEstimatedPageCount
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public abstract long getEstimatedPageCount(BaseContainerHandle handle, int flag) throws StandardException;
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainerHandle.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainerHandle.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainerHandle.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseContainerHandle.java Thu Mar  8 14:25:41 2007
@@ -170,7 +170,7 @@
 
 		@see BaseContainer#addPage
 		@see ContainerHandle#addPage
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Page addPage() throws StandardException 
     {
@@ -188,7 +188,7 @@
         will usually mean releasing any free pages located at the end of the
         file using the java truncate() interface.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void compressContainer() throws StandardException 
     {
@@ -218,7 +218,7 @@
 
 		@see BaseContainer#addPage
 		@see ContainerHandle#addPage
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Page addPage(int flag) throws StandardException {
 
@@ -284,7 +284,7 @@
 		Remove a page from the container.  
 
 		@see ContainerHandle#removePage
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void removePage(Page page) throws StandardException
 	{
@@ -427,7 +427,7 @@
 
 	/**
 		@see ContainerHandle#getEstimatedRowCount
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public long getEstimatedRowCount(int flag) throws StandardException
 	{
@@ -438,7 +438,7 @@
 
 	/**
 		@see ContainerHandle#setEstimatedRowCount
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public void setEstimatedRowCount(long count, int flag) 
         throws StandardException
@@ -450,7 +450,7 @@
 
 	/**
 		@see ContainerHandle#getEstimatedPageCount
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public long getEstimatedPageCount(int flag) 
         throws StandardException
@@ -462,7 +462,7 @@
 
 	/**
 		@see ContainerHandle#flushContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public void flushContainer() 
         throws StandardException
@@ -480,7 +480,7 @@
 
 	/**
 		@see ContainerHandle#compactRecord
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public void compactRecord(RecordHandle record) 
         throws StandardException
@@ -518,7 +518,7 @@
 	/**
 		Get the container status.  
 
-		@exception StandardException Standard Cloudscape error policy		
+		@exception StandardException Standard Derby error policy		
 		@see RawContainerHandle#getContainerStatus
 	*/
 	public int getContainerStatus() throws StandardException
@@ -531,7 +531,7 @@
 	/**
 		remove the container
 
-		@exception StandardException Standard Cloudscape error policy		
+		@exception StandardException Standard Derby error policy		
 		@see RawContainerHandle#removeContainer
 	*/
 	public void removeContainer(LogInstant instant) throws StandardException
@@ -566,7 +566,7 @@
 
 
 	/**
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 		@see RawContainerHandle#dropContainer
 	*/
 	public void dropContainer(LogInstant instant, boolean drop) 
@@ -578,7 +578,7 @@
 	}
 
 	/**
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 		@see RawContainerHandle#getContainerVersion
 	*/
 	public long getContainerVersion() 
@@ -595,7 +595,7 @@
 		Caller must be prepared to handle freed, deallocated,or alloc page
 		Called by recovery ONLY.
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	public Page getAnyPage(long pageNumber) throws StandardException
 	{
@@ -651,7 +651,7 @@
 		Log all information necessary to recreate the container during a load
 		tran.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public ByteArray logCreateContainerInfo() 
         throws StandardException
@@ -665,7 +665,7 @@
 		Return a record handle that is initialized to the given page number and
         record id.
 
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 
 		@param pageNumber   the page number of the RecordHandle.
 		@param recordId     the record id of the RecordHandle.
@@ -786,7 +786,7 @@
 
 		@param waitForLock if true, wait on lock, otherwise, get lock no wait.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public boolean useContainer(
     boolean droppedOK, 
@@ -937,7 +937,7 @@
 	   checkpoint is taken after any log record is sent to the log stream but
 	   before the container is actually dirtied.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public void preDirty(boolean preDirtyOn) throws StandardException 
     {
@@ -950,7 +950,7 @@
 
 	/**
 		@see ContainerHandle#isTemporaryContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public boolean isTemporaryContainer() throws StandardException 
     {

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseDataFileFactory.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseDataFileFactory.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CachedPage.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CachedPage.java Thu Mar  8 14:25:41 2007
@@ -166,7 +166,7 @@
 	 * @return always true, higher levels have already checked the page number 
      *         is valid for an open.
      *
-     * @exception StandardException Standard Cloudscape policy.
+     * @exception StandardException Standard Derby policy.
      *
      * @see Cacheable#setIdentity
      **/

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerBasicOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerBasicOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerBasicOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerBasicOperation.java Thu Mar  8 14:25:41 2007
@@ -194,7 +194,7 @@
 		missing container in load tran should override this method to return
 		the recreated container
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected RawContainerHandle findContainerForRedoRecovery(
     RawTransaction tran) 
@@ -205,7 +205,7 @@
 	
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public boolean needsRedo(Transaction xact)
 		 throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerOperation.java Thu Mar  8 14:25:41 2007
@@ -150,7 +150,7 @@
 		If we are in load tran, and the operation is a create, the container
 		may not (should not?) exist yet.  We need to recreate it.
 
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby error policy.
 	 */
 	protected RawContainerHandle findContainerForRedoRecovery(
     RawTransaction xact)
@@ -170,7 +170,7 @@
 	}
 
 	/** 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public final void doMe(Transaction tran, LogInstant instant, 
 						   LimitObjectInput in)
@@ -215,7 +215,7 @@
 		@param CLRInstant the log instant of the CLR
 		@param in optional data
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void undoMe(Transaction tran, RawContainerHandle hdl,
 					   LogInstant CLRInstant, LimitObjectInput in)
@@ -249,7 +249,7 @@
 
 	/**
 		@see org.apache.derby.iapi.store.raw.Undoable
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Compensation generateUndo(Transaction tran, LimitObjectInput in)
 		 throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerUndoOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerUndoOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerUndoOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/ContainerUndoOperation.java Thu Mar  8 14:25:41 2007
@@ -117,7 +117,7 @@
 		@param in			optional data
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby error policy.
 
 		@see ContainerOperation#generateUndo
 	 */

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CopyRowsOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CopyRowsOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_BaseContainerHandle.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_BaseContainerHandle.java Thu Mar  8 14:25:41 2007
@@ -48,7 +48,7 @@
      * <p>
      *
 	 * @return A string of the form TABLE(conglomerate_id, container_id).
-     * @exception StandardException Standard Cloudscape Error
+     * @exception StandardException Standard Derby Error
 	 **/
     public String diag()
         throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_RecordId.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_RecordId.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_RecordId.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_RecordId.java Thu Mar  8 14:25:41 2007
@@ -47,7 +47,7 @@
      * <p>
      *
 	 * @return A string of the form TABLE(conglomerate_id, container_id).
-     * @exception StandardException Standard Cloudscape Error
+     * @exception StandardException Standard Derby Error
 	 **/
     public String diag()
         throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DeleteOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DeleteOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DirectAllocActions.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DirectAllocActions.java Thu Mar  8 14:25:41 2007
@@ -49,7 +49,7 @@
 		@param undoStatus		on undo, set the allocation status of the page
 								this value 
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void actionAllocatePage(RawTransaction t, BasePage allocPage, 
 								   long pageNumber, int doStatus, int undoStatus)
@@ -67,7 +67,7 @@
 		@param pageNumber		the next allocation page's number 
 		@param pageOffset		the next allocation page's page offset
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void actionChainAllocPage(RawTransaction t, BasePage allocPage, 
 								long pageNumber, long pageOffset)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/EncryptContainerOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/EncryptContainerOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InputStreamContainer.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InputStreamContainer.java Thu Mar  8 14:25:41 2007
@@ -115,7 +115,7 @@
 		occurs then ...
 
 		@see org.apache.derby.iapi.services.cache.Cacheable#clean
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public final void clean(boolean forRemove) throws StandardException {
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InsertOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InsertOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LoggableAllocActions.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LoggableAllocActions.java Thu Mar  8 14:25:41 2007
@@ -47,7 +47,7 @@
 		@param undoStatus		on undo, set the allocation status of the page
 								this value 
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void actionAllocatePage(RawTransaction t, BasePage allocPage, 
 								   long pageNumber, int doStatus, int undoStatus)
@@ -72,7 +72,7 @@
 		@param pageNumber		the next allocation page's number 
 		@param pageOffset		the next allocation page's page offset
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public void actionChainAllocPage(RawTransaction t, BasePage allocPage, 
 								long pageNumber, long pageOffset)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalPageOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalPageOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalPageOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalPageOperation.java Thu Mar  8 14:25:41 2007
@@ -131,7 +131,7 @@
 		be rolled back (redo only), overwrite this function to return null.
 
 		@see LogicalUndo
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 		@exception IOException Method may read from ObjectInput
 	*/
 
@@ -318,7 +318,7 @@
 
 	  @return the compensation operation that will rollback this change 
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException Method may read from ObjectInput
 
 	  @see PageBasicOperation
@@ -409,7 +409,7 @@
 		@param in			optional data for the rollback operation
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	*/
 	abstract public void undoMe(Transaction xact, BasePage undoPage, int undoRecordId,
 								LogInstant CLRinstant, LimitObjectInput in) 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalUndoOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalUndoOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalUndoOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LogicalUndoOperation.java Thu Mar  8 14:25:41 2007
@@ -156,7 +156,7 @@
 		@param in			optional data
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 	 */
 	public final void doMe(Transaction xact, LogInstant instant, LimitObjectInput in) 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageActions.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageActions.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageActions.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageActions.java Thu Mar  8 14:25:41 2007
@@ -52,7 +52,7 @@
      * @param delete			set the delete status to this value
      * @param undo				logical undo logic if necessary
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      * @see org.apache.derby.iapi.store.raw.Page#deleteAtSlot
      **/
 	public void actionDelete(
@@ -84,7 +84,7 @@
      * @return the next column to update in the row or,
      *         -1 if the update has been completed.
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      *
      * @see org.apache.derby.iapi.store.raw.Page#updateAtSlot
      **/
@@ -114,7 +114,7 @@
      * @param num_rows		how many rows to purge
      * @param recordIds		the recordIDs of the record (an array of num_rows)
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      *
      * @see org.apache.derby.iapi.store.raw.Page#purgeAtSlot
      **/
@@ -143,7 +143,7 @@
      *                      logic resides.   Null if logical undo is not 
      *                      necessary.
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      *
      * @see org.apache.derby.iapi.store.raw.Page#updateFieldAtSlot
      *
@@ -174,7 +174,7 @@
      *                          not necessary.
      * @param insertFlag		see Page value for insertFlag
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      *
      * @see org.apache.derby.iapi.store.raw.Page#insertAtSlot
      **/
@@ -209,7 +209,7 @@
      * @param recordIds		    an array of record ids to use in the 
      *                          destination page
      *
-     * @exception StandardException Standard Cloudscape policy.
+     * @exception StandardException Standard Derby policy.
      **/
 	public void actionCopyRows(
     RawTransaction  t, 
@@ -233,7 +233,7 @@
      * @param t             	The transaction
      * @param page				that page to be invalidated
      *
-     * @exception StandardException Standard Cloudscape policy.  
+     * @exception StandardException Standard Derby policy.  
      **/
 	public void actionInvalidatePage(
     RawTransaction  t, 
@@ -254,7 +254,7 @@
      *                          initialized.
      * @param pageFormatId		The format Id of the page being initialized.
      *
-     * @exception StandardException Standard Cloudscape policy.
+     * @exception StandardException Standard Derby policy.
      **/
 	public void actionInitPage(
     RawTransaction  t, 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageBasicOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageBasicOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageBasicOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PageBasicOperation.java Thu Mar  8 14:25:41 2007
@@ -152,7 +152,7 @@
 	/** Returns true if this op should be redone during recovery redo,
 	    if so, get and latched the page.
 
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	 */
 	public final boolean needsRedo(Transaction xact)
 		 throws StandardException
@@ -220,7 +220,7 @@
 		WARNING: If a log operation extends this class, and the operation has optional data,
 		it MUST overwrite this method to return a ByteArray that contains the optional data. 
 
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	*/
 	public ByteArray getPreparedLog() throws StandardException
 	{
@@ -270,7 +270,7 @@
 		@return null if container is dropped and committed (possibly
 		stubbified), else return the latched page
 
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	 */
 	public final BasePage findpage(Transaction xact) throws StandardException 
 	{
@@ -362,7 +362,7 @@
 		Subclass (e.g., init page) that wishes to do something about missing
 		pages in load tran should override this method to return the page
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	protected BasePage getPageForRedoRecovery(Transaction xact)
 		 throws StandardException
@@ -397,7 +397,7 @@
 		@param in			optional data for the rollback operation
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	*/
 	abstract public void restoreMe(Transaction xact, BasePage undoPage,
 								LogInstant CLRinstant, LimitObjectInput in) 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalPageOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalPageOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalPageOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalPageOperation.java Thu Mar  8 14:25:41 2007
@@ -97,7 +97,7 @@
 
 	  @return the compensation operation that will rollback this change 
 
-	  @exception StandardException Standard Cloudscape policy.
+	  @exception StandardException Standard Derby policy.
 
 	  @see PageBasicOperation
 	  @see Undoable#generateUndo
@@ -138,7 +138,7 @@
 		@param in			optional data for the rollback operation
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	*/
 	abstract public void undoMe(Transaction xact, BasePage undoPage,
 								   LogInstant CLRinstant, LimitObjectInput in) 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalUndoOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalUndoOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalUndoOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PhysicalUndoOperation.java Thu Mar  8 14:25:41 2007
@@ -118,7 +118,7 @@
 		@param in			optional data
 
 		@exception IOException Can be thrown by any of the methods of InputStream.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 	 */
 	public final void doMe(Transaction xact, LogInstant instant, LimitObjectInput in) 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PurgeOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PurgeOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer.java Thu Mar  8 14:25:41 2007
@@ -118,7 +118,7 @@
 
 	/**
 		Set container's identity
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Cacheable setIdentity(Object key) throws StandardException {
 
@@ -135,7 +135,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public Cacheable createIdentity(Object key, Object createParameter) throws StandardException {
 
@@ -157,7 +157,7 @@
 	/**
 		Remove the container
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void removeContainer(LogInstant instant, boolean leaveStub)
 		 throws StandardException
@@ -218,7 +218,7 @@
 
 		<BR> MT - thread safe
 		@exception IOException exception reading page
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void readPage(long pageNumber, byte[] pageData)
 		 throws IOException, StandardException
@@ -248,7 +248,7 @@
 
 		<BR> MT - thread safe
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException IO error accessing page
 	*/
 	protected void writePage(long pageNumber, byte[] pageData, boolean syncPage)
@@ -720,7 +720,7 @@
 	/**
 		flush the cache to ensure all of my pages are written to disk
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void flushAll() throws StandardException {
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer4.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer4.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer4.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer4.java Thu Mar  8 14:25:41 2007
@@ -162,7 +162,7 @@
      *
      *  <BR> MT - thread safe
      *  @exception IOException exception reading page
-     *  @exception StandardException Standard Cloudscape error policy
+     *  @exception StandardException Standard Derby error policy
      */
     protected void readPage(long pageNumber, byte[] pageData)
          throws IOException, StandardException
@@ -227,7 +227,7 @@
      *
      *  <BR> MT - thread safe
      *
-     *  @exception StandardException Standard Cloudscape error policy
+     *  @exception StandardException Standard Derby error policy
      *  @exception IOException IO error accessing page
      */
     protected void writePage(long pageNumber, byte[] pageData, boolean syncPage)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RemoveFileOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RemoveFileOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RemoveFileOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RemoveFileOperation.java Thu Mar  8 14:25:41 2007
@@ -136,7 +136,7 @@
 
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public boolean needsRedo(Transaction xact)
 		 throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SetReservedSpaceOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SetReservedSpaceOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/RawStore.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/RawStore.java Thu Mar  8 14:25:41 2007
@@ -374,7 +374,7 @@
 	 * Return the module providing XAresource interface to the transaction
      * table.
      *
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()
         throws StandardException
@@ -1046,7 +1046,7 @@
 
 	/**
 	 * Get JBMS properties relavent to raw store
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 */
 	public void getRawStoreProperties(PersistentSet set)
 		 throws StandardException
@@ -1060,7 +1060,7 @@
 	*/
 	/**
 		Freeze persistent store.  Reads can still happen, only cannot write.
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public void freezePersistentStore() throws StandardException
 	{
@@ -1072,7 +1072,7 @@
 
 	/**
 		Freeze persistent store.  Reads can still happen, only cannot write.
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public void unfreezePersistentStore() throws StandardException
 	{
@@ -1280,7 +1280,7 @@
 
 		@see CipherProvider#encrypt
 
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int encrypt(byte[] cleartext, int offset, int length,
 					   byte[] ciphertext, int outputOffset, 
@@ -1310,7 +1310,7 @@
 
 		@see CipherProvider#decrypt
 
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int decrypt(byte[] ciphertext, int offset, int length,
 					   byte[] cleartext, int outputOffset) 
@@ -374,7 +374,7 @@
      * table.
      *
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()
@@ -1046,7 +1046,7 @@
 	/**
 	 * Get JBMS properties relavent to raw store
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 */
 	public void getRawStoreProperties(PersistentSet set)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocExtent.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/AllocExtent.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseDataFileFactory.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BaseDataFileFactory.java Thu Mar  8 14:25:41 2007
@@ -529,7 +529,7 @@
 	/**
 		Database creation finished
 
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 	*/
 	public void createFinished() throws StandardException
 	{
@@ -562,7 +562,7 @@
 
 	/**
 		@see DataFactory#openDroppedContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public RawContainerHandle openDroppedContainer(
     RawTransaction  t, 
@@ -581,7 +581,7 @@
 
 	/**
 		@see DataFactory#openContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	private RawContainerHandle openContainer(
     RawTransaction  t, 
@@ -754,7 +754,7 @@
 	}
 
 	/** Add a container with a specified page size to a segment.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public long addContainer(
     RawTransaction  t, 
@@ -900,7 +900,7 @@
 	}
 
 	/** Add and load a stream container
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public long addAndLoadStreamContainer(
     RawTransaction  t, 
@@ -926,7 +926,7 @@
 		open an exsisting streamContainer
 
 		@see DataFactory#openStreamContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public StreamContainerHandle openStreamContainer(
     RawTransaction  t, 
@@ -962,7 +962,7 @@
 		<P>
 		This call will remove the container.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void dropStreamContainer(
     RawTransaction  t, 
@@ -1001,7 +1001,7 @@
 
 		called ONLY during recovery load tran.
 
-		@exception StandardException Standard Cloudscape Error policy
+		@exception StandardException Standard Derby Error policy
 	 */
 	public void reCreateContainerForRedoRecovery(
     RawTransaction  t, 
@@ -1040,7 +1040,7 @@
 		and all its pages deallocated. The container will be fully removed
 		at the commit time of the transaction.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void dropContainer(
     RawTransaction  t, 
@@ -1412,7 +1412,7 @@
 		Not implemented in this class - subclass who deals with side log must
 		override this.
 
-		@exception StandardException Cloudscape Standard Error Policy
+		@exception StandardException Derby Standard Error Policy
 	*/
 	private void syncSideLog(long bipLocation)
 		 throws StandardException
@@ -1474,7 +1474,7 @@
 	 *	This page is going from clean to dirty, this is a chance for the
 	 *	sub class to do something if so desired
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 */
 	private void pageToDirty(RawTransaction t, StoredPage page)
 		 throws StandardException
@@ -1486,7 +1486,7 @@
 	 * Get the loggable page action that is associated with this implementation
 	 *
 	 * @return the PageActions
 	 * @exception StandardExceptions Standard Cloudscape Error Policy
 	 */
 	private PageActions getLoggablePageActions() throws StandardException
 	{
@@ -2256,7 +2256,7 @@
 	/**
 		Called after recovery is performed.
 
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	*/
 	public void postRecovery() throws StandardException 
     {
@@ -1474,7 +1474,7 @@
 	 *	sub class to do something if so desired
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 */
 	private void pageToDirty(RawTransaction t, StoredPage page)
@@ -1486,7 +1486,7 @@
 	 *
 	 * @return the PageActions
-	 * @exception StandardExceptions Standard Cloudscape Error Policy
+	 * @exception StandardExceptions Standard Derby Error Policy
 	 */
 	private PageActions getLoggablePageActions() throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BasePage.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BasePage.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BasePage.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/BasePage.java Thu Mar  8 14:25:41 2007
@@ -430,7 +430,7 @@
 
 
 	/**
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@see Page#fetchFieldFromSlot
 	 */
 	public final RecordHandle fetchFieldFromSlot(
@@ -491,7 +491,7 @@
 	}
 
 	/** @see Page#insertAtSlot
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	 */
 	public RecordHandle insertAtSlot(
     int                     slot, 
@@ -598,7 +598,7 @@
 	}
 
 	/** @see Page#insert
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	 */
 	public final RecordHandle insert(
     Object[]   row, 
@@ -628,7 +628,7 @@
 		If handle is supplied then the record at that hanlde will be updated
 		to indicate it is a partial row and it has an overflow portion.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public RecordHandle insertAllowOverflow(
     int                     slot, 
@@ -903,7 +903,7 @@
 		@param handle			handle of the record for long row
 		@param overflowHandle	the overflow (continuation) pointer for the long row
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract void updateOverflowDetails(RecordHandle handle, RecordHandle overflowHandle)
 		throws StandardException;
@@ -916,7 +916,7 @@
 		@param handle			handle of the record for long row
 		@param overflowHandle	the overflow (continuation) pointer for the long row
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract void updateFieldOverflowDetails(RecordHandle handle, RecordHandle overflowHandle)
 		throws StandardException;
@@ -931,7 +931,7 @@
 		@param overflowHandle	the overflow (continuation) pointer
 								to the beginning of the long column
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract int appendOverflowFieldHeader(DynamicByteArrayOutputStream logBuffer, RecordHandle overflowHandle)
 		throws StandardException, IOException;
@@ -947,7 +947,7 @@
 		throws StandardException;
 
 	/** @see Page#updateAtSlot
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception StandardException	StandardException.newException(SQLState.UPDATE_DELETED_RECORD
 		if the record is already deleted
 		@exception StandardException	StandardException.newException(SQLState.CONTAINER_READ_ONLY
@@ -994,7 +994,7 @@
 		throws	StandardException;
 
 	/** @see Page#updateFieldAtSlot
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception StandardException	StandardException.newException(SQLState.UPDATE_DELETED_RECORD
 		if the record is already deleted
 		@exception StandardException	StandardException.newException(SQLState.CONTAINER_READ_ONLY
@@ -1529,7 +1529,7 @@
 		Get an exclusive latch on the page.
 		<BR>
 		MT - thread safe
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	*/
 	void setExclusive(BaseContainerHandle requester)
 		throws StandardException {
@@ -1771,7 +1771,7 @@
 		<BR>
 		MT - latched
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public abstract boolean entireRecordOnPage(int slot) 
 		 throws StandardException;
@@ -1813,7 +1813,7 @@
 		<BR>
 		MT - latched
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException IO error accessing page
 	*/
 	public int setDeleteStatus(int slot, boolean delete) throws StandardException, IOException {
@@ -1829,7 +1829,7 @@
 	/**
 		Mark this page as being deallocated
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	public void deallocatePage() throws StandardException
 	{
@@ -1850,7 +1850,7 @@
 
 	/**
 		Mark this page as being allocated and initialize it to a pristine page
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	public void initPage(int initFlag, long pageOffset) 
 		 throws StandardException 
@@ -2123,7 +2123,7 @@
 	  @param handle Handle to deleted or non-deleted record
 	  @see ContainerHandle#compactRecord
 
-	  @exception StandardException	Standard Cloudscape error policy
+	  @exception StandardException	Standard Derby error policy
 	*/
 	public void compactRecord(RecordHandle handle) throws StandardException
 	{
@@ -2292,7 +2292,7 @@
      * @return  false if a qualifier_list is provided and the row does not 
      *          qualifier (no row read in that case), else true.
      *
      * @exception StandardException	Standard Cloudscape error policy
      **/
 	protected abstract boolean restoreRecordFromSlot(
     int                     slot, 
@@ -2310,7 +2310,7 @@
 		<BR> MT - latched, page is latched when this methods is called.
 
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	protected abstract void restorePortionLongColumn(OverflowInputStream fetchStream)
 		throws StandardException, IOException;
@@ -2320,7 +2320,7 @@
 
 		<BR> MT - latched, page is latched when this methods is called.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract int newRecordId() throws StandardException;
 
@@ -2329,7 +2329,7 @@
 
 		<BR> MT - latched, page is latched when this methods is called.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract int newRecordIdAndBump() throws StandardException;
 
@@ -2341,7 +2341,7 @@
 
 		<BR> MT - latched, page is latched when this methods is called.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	protected abstract int newRecordId(int recordId) throws StandardException;
 
@@ -2351,7 +2351,7 @@
 
 		<BR> MT - latched, page is latched when this methods is called.
 
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	*/
 	public abstract boolean spaceForCopy(int num_rows, int[] spaceNeeded)
 		 throws StandardException;
@@ -2362,7 +2362,7 @@
 
 		<BR> MT - latched, page is latched when this methods is called.
 
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	*/
 	public abstract int getTotalSpace(int slot) throws StandardException;
 
@@ -2408,7 +2408,7 @@
 
 		<BR> MT - latched - page latch must be held
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException object exceeds the available data in the stream.
 
 	*/
@@ -2432,7 +2432,7 @@
 		@param headRowHandle	the recordHandle of the head row piece, used
 						for post commit cleanup for update. 
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract void logRecord(int slot, int flag, int recordId,
 								   FormatableBitSet validColumns, OutputStream out,
@@ -2467,7 +2467,7 @@
 		@param realSpaceOnPage	Being used in conjunction with realStartColumn,
 								to indicate the real free space left on the page.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract int logRow(
     int                     slot, 
@@ -2493,7 +2493,7 @@
 		@param fieldNumber Number of the field (starts at 0).
 		@param out		Where to write the logged form.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract void logField(int slot, int fieldNumber, OutputStream out)
 		throws StandardException, IOException;
@@ -2507,7 +2507,7 @@
 		@param column column version of the field.
 		@param out		Where to write the logged form.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract void logColumn(
     int                     slot, 
@@ -2527,7 +2527,7 @@
 		@param column		column version of the field.
 		@param out			Where to write the logged form.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	public abstract int logLongColumn(
     int                     slot, 
@@ -2543,7 +2543,7 @@
 
 		<BR> MT - latched - page latch must be held
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException Thrown by InputStream methods potential I/O errors
 		while writing the page
 		
@@ -2558,7 +2558,7 @@
 
 		<BR> MT - latched - page latch must be held
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException Thrown by InputStream methods and potential I/O errors
 		while writing the page.
 	*/
@@ -2572,7 +2572,7 @@
 
 		<BR> MT - latched - page latch must be held
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException Thrown by InputStream methods and potential I/O errors
 		while writing the page.
 	*/
@@ -2585,7 +2585,7 @@
 
 		<BR> MT - latched - page latch must be held
 		
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException Thrown by InputStream methods
 
 	*/
@@ -2602,7 +2602,7 @@
 		@param slot the slot to delete or undelete
 		@param delete set delete status to this value 
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException IO error accessing page
 	*/
 	public abstract void setDeleteStatus(LogInstant instant, int slot, boolean delete)
@@ -2616,7 +2616,7 @@
 		@param slot the slot to purge
 		@param recordId the id of the record that is to be purged
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException Thrown by potential I/O errors
 		while writing the page.
 	*/
@@ -2627,7 +2627,7 @@
 	/**
 		Subclass implementation of compactRecord.
 		@see BasePage#compactRecord
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected abstract void compactRecord(RawTransaction t, int slot, int recordId)
 		 throws StandardException;
@@ -2640,7 +2640,7 @@
 		@param instant the log instant of the log record
 		@param status the page status
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public abstract void setPageStatus(LogInstant instant, byte status)
 		throws StandardException;
@@ -2651,7 +2651,7 @@
 
 		All subtypes are expected to overwrite this method if it has something to clean up
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public abstract void initPage(LogInstant instant, byte status, 
 								  int recordId, boolean overflow, boolean reuse)
@@ -2659,7 +2659,7 @@
 
 	/**
 		Set the reserved space for this row to value.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public abstract void setReservedSpace(LogInstant instant, int slot, int value) 
 		 throws StandardException, IOException;
@@ -2292,7 +2292,7 @@
      *          qualifier (no row read in that case), else true.
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      **/
 	protected abstract boolean restoreRecordFromSlot(

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CachedPage.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CachedPage.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CopyRowsOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/CopyRowsOperation.java Thu Mar  8 14:25:41 2007
@@ -157,7 +157,7 @@
 	 */
 	/**
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby error policy.		
 	  
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -184,7 +184,7 @@
 	    to undo this operation, purge all records that were copied over.
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@see PhysicalPageOperation#undoMe
 	 */
 	public void undoMe(Transaction xact, BasePage undoPage,
@@ -215,7 +215,7 @@
 	 * restore the before image of the page
 	 *
 	 * @exception IOException problem reading the complete log record from the input stream
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 */
 	public void restoreMe(Transaction xact, BasePage undoPage,
 					   LogInstant CLRInstant, LimitObjectInput in)
@@ -239,7 +239,7 @@
 		Write the rows that are to be copied into this page
 
 		@exception IOException Can be thrown by any of the methods of ObjectOutput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 
 	*/
 	private void writeOptionalDataToBuffer(RawTransaction t, BasePage srcPage, int srcSlot)
@@ -215,7 +215,7 @@
 	 *
 	 * @exception IOException problem reading the complete log record from the input stream
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 */
 	public void restoreMe(Transaction xact, BasePage undoPage,

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_BaseContainerHandle.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/D_BaseContainerHandle.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DeleteOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DeleteOperation.java Thu Mar  8 14:25:41 2007
@@ -144,7 +144,7 @@
 		Mark the record as deleted on the page.
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -213,7 +213,7 @@
 		Restore the row stored in the optional data of the log record.
 
 		@exception IOException error reading from log stream
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void restoreLoggedRow(
     Object[]   row, 
@@ -249,7 +249,7 @@
 	/**
 	 * restore the before image of the page
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */
@@ -289,7 +289,7 @@
 	    if logical undo, writes out the row that was deleted
 
 		@exception IOException Can be thrown by any of the methods of ObjectOutput
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	*/
 	private void writeOptionalDataToBuffer(RawTransaction t)
 		throws StandardException, IOException
@@ -249,7 +249,7 @@
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DirectAllocActions.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/DirectAllocActions.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/EncryptContainerOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/EncryptContainerOperation.java Thu Mar  8 14:25:41 2007
@@ -152,7 +152,7 @@
      * @param instant   log instant for this operation.
      * @param in        unused by this log operation.
      *
      * @exception StandardException Standard Cloudscape error policy
      */
     public final void doMe(Transaction tran, LogInstant instant, 
                            LimitObjectInput in)
@@ -173,7 +173,7 @@
        that existed before the start of the database encryption is put back.
         
        @param tran the transaction that is undoing this operation
-       @exception StandardException Standard Cloudscape error policy
+       @exception StandardException Standard Derby error policy
     */
     public void undoMe(Transaction tran) throws StandardException
     {
@@ -192,7 +192,7 @@
      * encryption.
      * @param tran	the transaction doing the compensating
 	 * @param in	optional input; not used by this operation.
      * @exception StandardException Standard Cloudscape error policy
      */
     public Compensation generateUndo(Transaction tran, LimitObjectInput in)
         throws StandardException
@@ -152,7 +152,7 @@
      * @param in        unused by this log operation.
      *
-     * @exception StandardException Standard Cloudscape error policy
+     * @exception StandardException Standard Derby error policy
      */
     public final void doMe(Transaction tran, LogInstant instant, 
@@ -192,7 +192,7 @@
      * @param tran	the transaction doing the compensating
 	 * @param in	optional input; not used by this operation.
-     * @exception StandardException Standard Cloudscape error policy
+     * @exception StandardException Standard Derby error policy
      */
     public Compensation generateUndo(Transaction tran, LimitObjectInput in)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/FileContainer.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/FileContainer.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/FileContainer.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/FileContainer.java Thu Mar  8 14:25:41 2007
@@ -552,7 +552,7 @@
      * passed in identity, this object will no identity until after this 
      * method returns.
      *
      * @exception StandardException Cloudscape Standard error policy
      **/
 	abstract void createContainer(ContainerKey newIdentity) 
         throws StandardException;
@@ -630,7 +630,7 @@
      *     derby.storage.pageReservedSpace
      *     derby.storage.minimumRecordSize
      *     derby.storage.reusableRecordId
-	 *     cloudsacpe.storage.initialPages
+     *     derby.storage.initialPages
      * <p>
      * To get the value of a particular property add it to the property list,
      * and on return the value of the property will be set to it's current 
@@ -706,7 +706,7 @@
 
 		<BR> MT - single thread required - Enforced by caller.
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 		@exception IOException error in reading the header from file
 	*/
 	protected void readHeader(DataInput fileData) 
@@ -787,7 +787,7 @@
 		The container Header array must be written by or of
 		the same format as put together by writeHeaderFromArray.
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 		@exception IOException error in reading the header from file
 	*/
 	private void readHeaderFromArray(byte[] a)
@@ -861,7 +861,7 @@
 	/**
 		Write the container header to a page array (the first allocation page)
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 		@exception IOException error in writing the header to file
 	*/
 	protected void writeHeader(byte[] pageData)
@@ -883,7 +883,7 @@
 
 		<BR> MT - single thread required - Enforced by caller
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 		@exception IOException error in writing the header to file
 	 */
 	protected void writeHeader(DataOutput fileData, boolean create, byte[] epage)
@@ -989,7 +989,7 @@
 		Log all information on the container creation necessary to recreate the
 		container during a load tran.
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	protected ByteArray logCreateContainerInfo() 
 		 throws  StandardException
@@ -1211,7 +1211,7 @@
 		@param page the page to be deallocated.  It is latched upon entry and
 		will be unlatched by the caller of this function
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	protected void deallocatePage(BaseContainerHandle handle, BasePage page)
 		 throws StandardException
@@ -1338,7 +1338,7 @@
 	  #param allocHandle - the container handle opened by the ntt, 
 						use this to latch the alloc page
 
-	  @exception StandardException Standard Cloudscape error policy 
+	  @exception StandardException Standard Derby error policy 
 	*/
 	protected void compressContainer(
     RawTransaction      ntt,
@@ -1507,7 +1507,7 @@
 	  #param allocHandle - the container handle opened by the ntt, 
 						use this to latch the alloc page
 
-	  @exception StandardException Standard Cloudscape error policy 
+	  @exception StandardException Standard Derby error policy 
 	*/
 	protected BasePage newPage(BaseContainerHandle userHandle,
 							   RawTransaction ntt,
@@ -2275,7 +2275,7 @@
 		@param reuse is true if we are reusing a page that has 
 				already been initialized once
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	protected BasePage initPage(BaseContainerHandle allochandle, 
 								PageKey pkey,
@@ -2383,7 +2383,7 @@
 
 		<BR> MT - thread safe
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	private BasePage getUserPage(BaseContainerHandle handle, long pageNumber,
         boolean overflowOK, boolean wait)
@@ -2459,7 +2459,7 @@
 
 		<BR> MT - thread safe
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected BasePage getPage(BaseContainerHandle handle, long pageNumber,
         boolean wait)
@@ -2473,7 +2473,7 @@
 	/**
 		Get any old page - turn off all validation
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	protected BasePage getAnyPage(BaseContainerHandle handle, long pageNumber) throws StandardException
 	{
@@ -2658,7 +2658,7 @@
 		Get an alloc page - only accessible to the raw store 
 		(container and recovery)
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	protected BasePage getAllocPage(long pageNumber) throws StandardException 
 	{
@@ -2689,7 +2689,7 @@
 		Get only a valid, non-overflow page.  If page number is either invalid
 		or overflow, returns null
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	protected BasePage getHeadPage(BaseContainerHandle handle, long pageNumber,
         boolean wait)
@@ -2702,7 +2702,7 @@
 	/**
 		Get the first valid page in the container
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	protected BasePage getFirstHeadPage(BaseContainerHandle handle, boolean wait)
 		 throws StandardException
@@ -2712,7 +2712,7 @@
 
 	/**
 		Get the next page in the container.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected BasePage getNextHeadPage(BaseContainerHandle handle,
         long pageNumber, boolean wait)
@@ -2882,7 +2882,7 @@
 
 	/**
 		Get a potentially suitable page for insert and latch it.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected BasePage getPageForInsert(BaseContainerHandle handle,
 										int flag)
@@ -3077,7 +3077,7 @@
 
 	/**
 		@see ContainerHandle#getEstimatedPageCount
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public long getEstimatedPageCount(BaseContainerHandle handle, int flag)
 		 throws StandardException 
@@ -3109,7 +3109,7 @@
 
 		<BR> MT - thread safe
 		@exception IOException error reading page
-		@exception StandardException standard cloudscape error message
+		@exception StandardException standard Derby error message
 	*/
 	protected abstract void readPage(long pageNumber, byte[] pageData)
 		 throws IOException, StandardException;
@@ -3120,7 +3120,7 @@
 
 		<BR> MT - thread safe
 		@exception IOException error writing page
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected abstract void writePage(long pageNumber, byte[] pageData, boolean syncPage) 
 		throws IOException, StandardException;
@@ -3133,7 +3133,7 @@
 
 		<BR>MT - MT safe.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected void decryptPage(byte[] pageData, int pageSize)
 		 throws StandardException
@@ -3165,7 +3165,7 @@
 		<BR> MT - not safe, call within synchronized block and only use the
 		returned byte array withing synchronized block. 
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected byte[] encryptPage(byte[] pageData, 
                                  int pageSize, 
@@ -552,7 +552,7 @@
      * method returns.
      *
-     * @exception StandardException Cloudscape Standard error policy
+     * @exception StandardException Derby Standard error policy
      **/
 	abstract void createContainer(ContainerKey newIdentity) 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InitPageOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InitPageOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InitPageOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InitPageOperation.java Thu Mar  8 14:25:41 2007
@@ -139,7 +139,7 @@
 		Mark the page as valid, and clear out any crud from the page
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -165,7 +165,7 @@
 		This routine is called as the last resort of find page, the container
 		handle has already been found and it is not dropped.
 
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	*/
 	protected BasePage getPageForRedoRecovery(Transaction xact)
 		 throws StandardException
@@ -217,7 +217,7 @@
 	/** 
 	 * restore the before image of the page
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */
@@ -217,7 +217,7 @@
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InputStreamContainer.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InputStreamContainer.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InsertOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InsertOperation.java Thu Mar  8 14:25:41 2007
@@ -164,7 +164,7 @@
 	 */
 	/**
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	  
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -183,7 +183,7 @@
 		All logical undo logic has already been taken care of by generateUndo.
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 
 		@see LogicalPageOperation#undoMe
 	*/
@@ -252,7 +252,7 @@
 		Restore the row stored in the optional data of the log record.
 
 		@exception IOException error reading from log stream
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void restoreLoggedRow(Object[] row, LimitObjectInput in)
 		throws StandardException, IOException
@@ -286,7 +286,7 @@
 	/**
 	 * restore the before image of the page
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */
@@ -336,7 +336,7 @@
 		Writes out the row that is to be inserted as the optional data.
 
 		@exception IOException Can be thrown by any of the methods of ObjectOutput
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	*/
 	private void writeOptionalDataToBuffer(
     RawTransaction          t, 
@@ -286,7 +286,7 @@
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InvalidatePageOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InvalidatePageOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InvalidatePageOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/InvalidatePageOperation.java Thu Mar  8 14:25:41 2007
@@ -110,7 +110,7 @@
 		Mark the page as being invalidated
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -147,7 +147,7 @@
 	/**
 	 * restore the before image of the page
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */
@@ -147,7 +147,7 @@
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LoggableAllocActions.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/LoggableAllocActions.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PurgeOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/PurgeOperation.java Thu Mar  8 14:25:41 2007
@@ -155,7 +155,7 @@
 		Apply the purge operation to the page.
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -183,7 +183,7 @@
 		Undo the purge operation on the page.
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 
 		@see PhysicalPageOperation#undoMe
 	*/
@@ -206,7 +206,7 @@
 	/**
 	 * restore the before image of the page
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */
@@ -232,7 +232,7 @@
 		Write out the purged record from the page.  Used for undo only.
 
 		@exception IOException Can be thrown by any of the methods of ObjectOutput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	*/
 	private void writeOptionalDataToBuffer(RawTransaction t, boolean needDataLogged)
 		throws StandardException, IOException
@@ -206,7 +206,7 @@
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/RAFContainer.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SetReservedSpaceOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SetReservedSpaceOperation.java Thu Mar  8 14:25:41 2007
@@ -115,7 +115,7 @@
 	 */
 	/**
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.		
+		@exception StandardException Standard Derby policy.		
 	  
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -142,7 +142,7 @@
 	/**
 	 * restore the before image of the page
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */
@@ -142,7 +142,7 @@
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream